@@ -957,15 +957,17 @@ amcheck <- function(x,m=5,p2s=1,frontend=FALSE,idvars=NULL,logs=NULL,
     }
   }
 
-  if (is.data.frame(x)) {
-    lmcheck <- lm(I(rnorm(AMn))~ ., data = x[,idcheck, drop = FALSE])
-  } else {
-    lmcheck <- lm(I(rnorm(AMn))~ ., data = as.data.frame(x[,idcheck, drop = FALSE]))
-  }
-  if (any(is.na(coef(lmcheck)))) {
-    bad.var <- names(x[,idcheck])[which(is.na(coef(lmcheck))) - 1]
-    bar.var <- paste(bad.var, collapse = ", ")
-    stop(paste("The variable ",bad.var,"is perfectly collinear with another variable in the data.\n"))
+  if (nrow(na.omit(x[,idcheck,drop=FALSE])) > ncol(x[,idcheck,drop=FALSE])) {
+      if (is.data.frame(x)) {
+          lmcheck <- lm(I(rnorm(AMn))~ ., data = x[,idcheck, drop = FALSE])
+      } else {
+          lmcheck <- lm(I(rnorm(AMn))~ ., data = as.data.frame(x[,idcheck, drop = FALSE]))
+      }
+      if (any(is.na(coef(lmcheck)))) {
+          bad.var <- colnames(x[,idcheck])[which(is.na(coef(lmcheck))) - 1]
+          bar.var <- paste(bad.var, collapse = ", ")
+          warning(paste("The variable",bad.var,"is perfectly collinear with another variable in the data.\n"))
+      }
   }
 
   return(list(m=m,priors=priors))
